@@ -1,118 +1,85 @@
-"""M2Crypto support for Python 1.5.2 and Python 2.x's httplib. 
+from __future__ import print_function
+
+"""M2Crypto support for Python 2.x's httplib.
 
 Copyright (c) 1999-2002 Ng Pheng Siong. All rights reserved."""
 
-RCS_id='$Id: isaac.httpslib.py 299 2005-06-09 17:32:28Z heikki $'
+import string
 
-import string, sys
-from httplib import *
-import SSL
+from M2Crypto import SSL
 
-if sys.version[0] == '2':
-    
-    if sys.version[:3] in ['2.1', '2.2']:
-        # In 2.1 and above, httplib exports "HTTP" only.
-        from httplib import HTTPConnection, HTTPS_PORT
-        # ISS Added:
-        from httplib import HTTPResponse,FakeSocket
+from httplib import FakeSocket, HTTP, HTTPConnection, HTTPResponse, HTTPS_PORT
 
-    class HTTPSConnection(HTTPConnection):
-    
-        """
-        This class allows communication via SSL using M2Crypto.
-        """
-    
-        default_port = HTTPS_PORT
-    
-        def __init__(self, host, port=None, **ssl):
-            keys = ssl.keys()
-            try: 
-                keys.remove('key_file')
-            except ValueError:
-                pass
-            try:
-                keys.remove('cert_file')
-            except ValueError:
-                pass
-            try:
-                keys.remove('ssl_context')
-            except ValueError:
-                pass
-            if keys:
-                raise IllegalKeywordArgument()
-            try:
-                self.ssl_ctx = ssl['ssl_context']
-                assert isinstance(self.ssl_ctx, SSL.Context)
-            except KeyError:
-                self.ssl_ctx = SSL.Context('sslv23')
-            HTTPConnection.__init__(self, host, port)
-    
-        def connect(self):
-            self.sock = SSL.Connection(self.ssl_ctx)
-            self.sock.connect((self.host, self.port))
-    
-        def close(self):
-            # This kludges around line 545 of httplib.py,
-            # which closes the connection in this object;
-            # the connection remains open in the response
-            # object.
-            #
-            # M2Crypto doesn't close-here-keep-open-there,
-            # so, in effect, we don't close until the whole 
-            # business is over and gc kicks in.
-            #
-            # Long-running callers beware leakage.
-            #
-            # 05-Jan-2002: This module works with Python 2.2,
-            # but I've not investigated if the above conditions
-            # remain.
+
+class HTTPSConnection(HTTPConnection):
+
+    """
+    This class allows communication via SSL using M2Crypto.
+    """
+
+    default_port = HTTPS_PORT
+
+    def __init__(self, host, port=None, **ssl):
+        keys = ssl.keys()
+        try:
+            keys.remove('key_file')
+        except ValueError:
             pass
+        try:
+            keys.remove('cert_file')
+        except ValueError:
+            pass
+        try:
+            keys.remove('ssl_context')
+        except ValueError:
+            pass
+        if keys:
+            raise ValueError()
+        try:
+            self.ssl_ctx = ssl['ssl_context']
+            assert isinstance(self.ssl_ctx, SSL.Context)
+        except KeyError:
+            self.ssl_ctx = SSL.Context('sslv23')
+        HTTPConnection.__init__(self, host, port)
 
+    def connect(self):
+        self.sock = SSL.Connection(self.ssl_ctx)
+        self.sock.connect((self.host, self.port))
 
-    class HTTPS(HTTP):
-        
-        _connection_class = HTTPSConnection
-    
-        def __init__(self, host='', port=None, **ssl):
-            HTTP.__init__(self, host, port)
-            try:
-                self.ssl_ctx = ssl['ssl_context']
-            except KeyError:
-                self.ssl_ctx = SSL.Context('sslv23')
+    def close(self):
+        # This kludges around line 545 of httplib.py,
+        # which closes the connection in this object;
+        # the connection remains open in the response
+        # object.
+        #
+        # M2Crypto doesn't close-here-keep-open-there,
+        # so, in effect, we don't close until the whole
+        # business is over and gc kicks in.
+        #
+        # Long-running callers beware leakage.
+        #
+        # 05-Jan-2002: This module works with Python 2.2,
+        # but I've not investigated if the above conditions
+        # remain.
+        pass
 
+class HTTPS(HTTP):
 
-elif sys.version[:3] == '1.5':
+    _connection_class = HTTPSConnection
 
-    class HTTPS(HTTP):
-    
-        def __init__(self, ssl_context, host='', port=None):
-            assert isinstance(ssl_context, SSL.Context)
-            self.debuglevel=0
-            self.file=None
-            self.ssl_ctx=ssl_context
-            if host:
-                self.connect(host, port)
-    
-        def connect(self, host, port=None):
-            # Cribbed from httplib.HTTP.
-            if not port:
-                i = string.find(host, ':')
-                if i >= 0:
-                    host, port = host[:i], host[i+1:]
-                    try: port = string.atoi(port)
-                    except string.atoi_error:
-                        raise socket.error, "nonnumeric port"
-            if not port: port = HTTPS_PORT
-            self.sock = SSL.Connection(self.ssl_ctx)
-            if self.debuglevel > 0: print 'connect:', (host, port)
-            self.sock.connect((host, port))
+    def __init__(self, host='', port=None, **ssl):
+        HTTP.__init__(self, host, port)
+        try:
+            self.ssl_ctx = ssl['ssl_context']
+        except KeyError:
+            self.ssl_ctx = SSL.Context('sslv23')
 
 # ISS Added.
 # From here, starts the proxy patch
 class HTTPProxyConnection(HTTPConnection):
     """
     This class provides HTTP access through (authenticated) proxies.
-    
+
     Example:
     If the HTTP proxy address is proxy.your.org:8080, an authenticated proxy
     (one which requires a username/password combination in order to serve
@@ -163,7 +130,7 @@ class HTTPProxyConnection(HTTPConnection):
         HTTPConnection.putrequest(self, method, newurl)
         # Add proxy-specific headers
         self._add_auth_proxy_header()
-        
+
     def _add_auth_proxy_header(self):
         """Adds an HTTP header for authenticated proxies
         """
@@ -173,13 +140,13 @@ class HTTPProxyConnection(HTTPConnection):
         # Authenticated proxy
         import base64
         userpass = "%s:%s" % (self.__username, self.__password)
-        enc_userpass = string.strip(base64.encodestring(userpass))
+        enc_userpass = base64.encodestring(userpass).strip()
         self.putheader("Proxy-Authorization", "Basic %s" % enc_userpass)
 
 class HTTPSProxyResponse(HTTPResponse):
     """
     Replacement class for HTTPResponse
-    Proxy responses (made through SSL) have to keep the connection open 
+    Proxy responses (made through SSL) have to keep the connection open
     after the initial request, since the connection is tunneled to the SSL
     host with the CONNECT method.
     """
@@ -189,7 +156,7 @@ class HTTPSProxyResponse(HTTPResponse):
 
 class HTTPSProxyConnection(HTTPProxyConnection):
     """This class provides HTTP access through (authenticated) proxies.
-    
+
     Example:
     If the HTTP proxy address is proxy.your.org:8080, an authenticated proxy
     (one which requires a username/password combination in order to serve
@@ -209,8 +176,8 @@ class HTTPSProxyConnection(HTTPProxyConnection):
 
     def __init__(self, proxy, host, port=None, username=None, password=None, **x509):
         for key in x509.keys():
-           if key not in ['cert_file', 'key_file','ssl_context']:
-                raise IllegalKeywordArgument()
+            if key not in ['cert_file', 'key_file', 'ssl_context']:
+                raise ValueError()
         self.key_file = x509.get('key_file')
         self.cert_file = x509.get('cert_file')
         #ISS Added
@@ -219,12 +186,12 @@ class HTTPSProxyConnection(HTTPProxyConnection):
         HTTPProxyConnection.__init__(self, proxy, host, port, username, password)
 
     def connect(self):
-        """Connect (using SSL) to the host and port specified in __init__ 
+        """Connect (using SSL) to the host and port specified in __init__
         (through a proxy)."""
         import socket
         # Set the connection with the proxy
         HTTPProxyConnection.connect(self)
-        # Use the stock HTTPConnection putrequest 
+        # Use the stock HTTPConnection putrequest
         host = "%s:%s" % (self._host, self._port)
         HTTPConnection.putrequest(self, "CONNECT", host)
         # Add proxy-specific stuff
@@ -259,7 +226,7 @@ class HTTPSProxyConnection(HTTPProxyConnection):
            # Fake the socket
            ssl = socket.ssl(self.sock, self.key_file, self.cert_file)
            self.sock = FakeSocket(self.sock, ssl)
-        if self.debuglevel > 0: print 'socket type:', self.sock
+        if self.debuglevel > 0: print('socket type:', self.sock)
 
     def putrequest(self, method, url):
         """Send a request to the server.
